# Coordination Health Dashboard

Generated 2026-03-21

79.7
healthy
Clash Trajectory
67.9
Recurring Clashes
100.0
Approval Rate
73.2
RFI Response
83.3
Meeting Decisions
76.0
Statistical Models
Exponential Decay Model
Decay rate: 0.0103 (stalled)
Near-zero projected: 2026-06-05 (113d from last round)
RFI Survival Analysis (Kaplan-Meier)
Censored P50: 3.0 biz days, Censored P90: 10.0 biz days (7 open RFIs as right-censored)
Attendance-Decision Correlation
r=-0.2736, p=0.5999 (Not significant)
Industry Benchmarks
recurring_clash_rate
100th
Your Recurring clash rate (%) of 0.0 is better than 100% of projects.
rfi_response_p90_days
84th
Your RFI 90th percentile response time (business days) of 5.0 is better than 84% of projects.
meeting_decision_rate
86th
Your Meeting decision resolution rate (%) of 76.0 is better than 86% of projects.